
GC content bias
---

#### Read coverage at the 16S rRNA gene regions of the Fervidobacterium pennivorans genome from the [MBARC-26](https://doi.org/10.1038/sdata.2016.81) dataset

![GC_bias_FP](images/FP_read_coverage.png)

#### GC bias report for this genome

![GC_bias_FP](images/FP_GC_bias.png)

+ Vertical blue line:		          Average GC content of the Genome
+ Vertical orange line: 	          Average GC content of the two 16S rRNA genes
+ Horizontal black line (left panel): Average read coverage of the genome 
